@@ -165,6 +165,7 @@ register(hc.equal_to_ignoring_case,
 register(hc.equal_to_ignoring_whitespace,
          'be_equal_to_ignoring_whitespace')
 register(hc.contains_string,
+         'substr', 'have_the_substr', 'contain_the_substr',
          'substring', 'have_the_substring', 'contain_the_substring')
 register(hc.ends_with,
          'end_with')
@@ -529,3 +530,35 @@ class Changes(BaseMatcher):
 
 register(Changes,
          'change', 'changes', 'modify', 'modifies')
+
+
+class Callback(BaseMatcher):
+    """ Checks against an user supplied callback """
+
+    def __init__(self, callback):
+        self.callback = callback
+
+    def _matches(self, item):
+        self.error = None
+        try:
+            return bool(self.callback(item))
+        except Exception as ex:
+            self.error = str(ex)
+            return False
+
+    def describe_to(self, desc):
+        desc.append_text('passses callback ')
+        if isinstance(self.callback, type(lambda: None)) and self.callback.__name__ == '<lambda>':
+            desc.append_text(self.callback.__name__)
+        else:
+            desc.append_text('{0}'.format(self.callback))
+
+    def describe_mismatch(self, item, desc):
+        if self.error:
+            desc.append_text('gave an exception "%s"' % self.error)
+        else:
+            desc.append_text('returned False')
+
+
+register(Callback,
+         'callback', 'pass', 'pass_callback')
